emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals-release/org 4f6bf89547 1/2: Fix BibTeX spelled as Bibte


From: ELPA Syncer
Subject: [elpa] externals-release/org 4f6bf89547 1/2: Fix BibTeX spelled as Bibtex
Date: Tue, 7 Mar 2023 08:59:06 -0500 (EST)

branch: externals-release/org
commit 4f6bf89547f77936abedf5b1a95ae2ce53dcdbbb
Author: Rudolf Adamkovič <salutis@me.com>
Commit: Ihor Radchenko <yantar92@posteo.net>

    Fix BibTeX spelled as Bibtex
    
    * lisp/ol-bibtex.el: Spell BibTeX correctly
    * etc/ORG-NEWS (Org-BibTeX -- major improvements): Spell BibTeX correctly
---
 etc/ORG-NEWS      |  2 +-
 lisp/ol-bibtex.el | 22 +++++++++++-----------
 2 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index d610a63b09..b75ea08a3c 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -6540,7 +6540,7 @@ that Calc formulas can operate on them.
 
 *** Hyperlinks
 
-**** Org-Bibtex -- major improvements
+**** Org-BibTeX -- major improvements
 
      Provides support for managing bibtex bibliographical references
      data in headline properties.  Each headline corresponds to a
diff --git a/lisp/ol-bibtex.el b/lisp/ol-bibtex.el
index 7d6ed85345..fd9517233e 100644
--- a/lisp/ol-bibtex.el
+++ b/lisp/ol-bibtex.el
@@ -86,8 +86,8 @@
 ;;   the active region, then call `org-bibtex-write' in a .org file to
 ;;   insert a heading for the read bibtex entry
 ;;
 ;; - All Bibtex information is taken from the document compiled by
 ;;   Andrew Roberts from the Bibtex manual, available at
 ;;   https://www.andy-roberts.net/res/writing/latex/bibentries.pdf
 ;;
 ;;; History:
@@ -99,7 +99,7 @@
 ;; and then implemented by Bastien Guerry.
 ;;
 ;; Eric Schulte eventually added the functions for translating between
 ;; Org headlines and Bibtex entries, and for fleshing out the Bibtex
 ;; fields of existing Org headlines.
 ;;
 ;; Org mode loads this module by default - if this is not what you want,
@@ -144,7 +144,7 @@
 (declare-function org-search-view "org-agenda" (&optional todo-only string 
edit-at))
 
 
-;;; Bibtex data
+;;; BibTeX data
 (defvar org-bibtex-types
   '((:article
      (:description . "An article from a journal or magazine")
@@ -202,7 +202,7 @@
      (:description . "A document having an author and title, but not formally 
published.")
      (:required :author :title :note)
      (:optional :month :year :doi :url)))
-  "Bibtex entry types with required and optional parameters.")
+  "BibTeX entry types with required and optional parameters.")
 
 (defvar org-bibtex-fields
   '((:address      . "Usually the address of the publisher or other type of 
institution.  For major publishing houses, van Leunen recommends omitting the 
information entirely.  For small publishers, on the other hand, you can help 
the reader by giving the complete address.")
@@ -231,7 +231,7 @@
     (:url          . "Uniform resource locator.")
     (:volume       . "The volume of a journal or multi-volume book.")
     (:year         . "The year of publication or, for an unpublished work, the 
year it was written.  Generally it should consist of four numerals, such as 
1984, although the standard styles can handle any year whose last four 
nonpunctuation characters are numerals, such as '(about 1984)'"))
-  "Bibtex fields with descriptions.")
+  "BibTeX fields with descriptions.")
 
 (defvar org-bibtex-entries nil
   "List to hold parsed bibtex entries.")
@@ -439,7 +439,7 @@ at point."
     (error "Field:%s is not known" field))
   (save-window-excursion
     (let* ((name (substring (symbol-name field) 1))
-          (buf-name (format "*Bibtex Help %s*" name)))
+          (buf-name (format "*BibTeX Help %s*" name)))
       (with-output-to-temp-buffer buf-name
        (princ (cdr (assoc field org-bibtex-fields))))
       (with-current-buffer buf-name (visual-line-mode 1))
@@ -496,7 +496,7 @@ With optional argument OPTIONAL, also prompt for optional 
fields."
     (org-bibtex-autokey)))
 
 
 ;;; Bibtex link functions
 (org-link-set-parameters "bibtex"
                         :follow #'org-bibtex-open
                         :store #'org-bibtex-store-link)
@@ -593,13 +593,13 @@ ARG, when non-nil, is a universal prefix argument.  See
 (add-hook 'org-execute-file-search-functions 
'org-execute-file-search-in-bibtex)
 
 
-;;; Bibtex <-> Org headline translation functions
+;;; BibTeX <-> Org headline translation functions
 (defun org-bibtex (filename)
   "Export each headline in the current file to a bibtex entry.
 Headlines are exported using `org-bibtex-headline'."
   (interactive
    (list (read-file-name
-         "Bibtex file: " nil nil nil
+         "BibTeX file: " nil nil nil
          (let ((file (buffer-file-name (buffer-base-buffer))))
            (and file
                 (file-name-nondirectory
@@ -619,7 +619,7 @@ Headlines are exported using `org-bibtex-headline'."
             nil))))
     (when error-point
       (goto-char error-point)
-      (message "Bibtex error at %S" (nth 4 (org-heading-components))))))
+      (message "BibTeX error at %S" (nth 4 (org-heading-components))))))
 
 (defun org-bibtex-check (&optional optional)
   "Check the current headline for required fields.
@@ -86,8 +86,8 @@
 ;;   insert a heading for the read bibtex entry
 ;;
-;; - All Bibtex information is taken from the document compiled by
-;;   Andrew Roberts from the Bibtex manual, available at
+;; - All BibTeX information is taken from the document compiled by
+;;   Andrew Roberts from the BibTeX manual, available at
 ;;   https://www.andy-roberts.net/res/writing/latex/bibentries.pdf
 ;;
@@ -99,7 +99,7 @@
 ;;
 ;; Eric Schulte eventually added the functions for translating between
-;; Org headlines and Bibtex entries, and for fleshing out the Bibtex
+;; Org headlines and BibTeX entries, and for fleshing out the BibTeX
 ;; fields of existing Org headlines.
 ;;
@@ -496,7 +496,7 @@ With optional argument OPTIONAL, also prompt for optional 
 
 
-;;; Bibtex link functions
+;;; BibTeX link functions
 (org-link-set-parameters "bibtex"
                         :follow #'org-bibtex-open



reply via email to

[Prev in Thread] Current Thread [Next in Thread]